<?php

/**
 * @file
 * Migrate Author given in .csv format.
 */

/**
 * Implementation of WordPressMigration, for authors.
 */
class WordPressAuthorMigration extends Migration {
  public $contenttype = 'author';
  public $file = 'migrate/inbox/author.csv';
  public $defaultuid = 1;

  /**
   * Set it up : Initialisation.
   */
  public function __construct() {
    parent::__construct();

    $this->description = "Migrate authors from a CSV file";

    $this->map = new MigrateSQLMap(
      $this->machineName,
      array(
        'userid' => array(
          'type' => 'int',
          'unsigned' => TRUE,
          'description' => 'author id',
        ),
      ),
      MigrateDestinationNode::getKeySchema()
    );
    // CSV header, field names.
    // userid, username, firstname, lastname, displayname,email.
    $additional_fields = array(
      'uid' => 'user id looked up by username');
    $this->source = new MigrateSourceCSV(file_directory_path() . '/' . $this->file,
                                         array(),
                                         array('header_rows' => 1),
                                         $additional_fields
                                         );
    $this->destination = new MigrateDestinationNode($this->contenttype);

    $this->addFieldMapping('uid', 'uid')
      ->defaultValue($this->defaultuid);
    $this->addFieldMapping('title', 'displayname');
    $this->addFieldMapping('field_pm_author_first_name', 'firstname');
    $this->addFieldMapping('field_pm_author_last_name', 'lastname');
    $this->addFieldMapping('field_pm_author_email', 'email');
  }
  /**
   * Modify source row and add additional column uid.
   */
  public function prepareRow($row) {
    $author_uid = db_result(db_query("select uid from {users} where name = '%s'", $row->username));
    if ($author_uid) {
      $row->uid = $author_uid;
    }
  }
}
